'use strict'

var clone = require('lodash.clone')

/**
 * Will extract all chord from markdown content
 * @type {[type]}
 */
module.exports = class ChordTransposer {
  constructor (opts) {
    this._notes = [
      { index: 0, whole: 'A' },
      { index: 1, sharp: 'A#', flat: 'Bb' },
      { index: 2, whole: 'B' },
      { index: 3, whole: 'C' },
      { index: 4, sharp: 'C#', flat: 'Db' },
      { index: 5, whole: 'D' },
      { index: 6, sharp: 'D#', flat: 'Eb' },
      { index: 7, whole: 'E' },
      { index: 8, whole: 'F' },
      { index: 9, sharp: 'F#', flat: 'Gb' },
      { index: 10, whole: 'G' },
      { index: 11, sharp: 'G#', flat: 'Ab' }
    ]
  }

  _getChordRootIndex (chord) {
    var index = null

    this._notes.forEach(function (note) {
      if (note.whole === chord.root ||
          note.sharp === chord.root ||
          note.flat === chord.root) {
        index = note.index
        return
      }
    })

    return index
  }

  _getChordRootOverrideIndex (chord) {
    var index = null

    this._notes.forEach(function (note) {
      if (note.whole === chord.rootOverride ||
          note.sharp === chord.rootOverride ||
          note.flat === chord.rootOverride) {
        index = note.index
        return
      }
    })

    return index
  }

  _getNoteByIndex (index) {
    var selected_note = null
    this._notes.forEach(function (note) {
      if (note.index === index % 12) {
        selected_note = note
      }
    })

    return selected_note
  }

  transpose (chord_original, change_roots_value) {

    let chord_transposed = clone(chord_original)

    let original_root_index = this._getChordRootIndex(chord_original)
    let new_root_index = original_root_index + change_roots_value
    let note = this._getNoteByIndex(new_root_index)
    chord_transposed.root = note.whole || note.sharp

    let original_rootOverride_index = this._getChordRootOverrideIndex(chord_original)
    let new_rootOverride_index = original_rootOverride_index + change_roots_value
    note = this._getNoteByIndex(new_rootOverride_index)
    chord_transposed.rootOverride = note.whole || note.sharp

    return chord_transposed
  }

}
